#----------------------------------------------------------------
# Copyright (c) 2002 Benjamin Crowell, all rights reserved.
#
# This software is available under version 2 of the GPL license.
# The software is copyrighted, and you must agree to the
# license in order to have permission to copy it. The full
# text of the license is given in the file titled Copying.
#
#----------------------------------------------------------------


use strict;

use MyWords;




=head2 Input.pm

The Input class is a way of checking a string input by the user
to see if it's valid. It also contains information about the
default value and the prompt, which are only for convenience ---
Input's methods don't use them. Synopsis:

  $i = Input->new(
         KEY=>"file_name",
         PROMPT=>"Filename",
         DEFAULT=>"foo.bar",
         TYPE=>"numeric",MIN=>"...",MAX=>"..."
  );
  $i = Input->new(
         ...
         TYPE=>"string",BLANK_ALLOWED=>1
  );
  if ($i->check($x)) { $error_code = ($i->check($x))[0]; ...}
          # ...may have other error info in [1], ...

=cut

package Input;

sub new {
    my $class = shift;
    my %args = (
		KEY=>"",
		PROMPT=>"",
		DEFAULT=>"",
		TYPE=>"numeric",
		MIN=>"",
		MAX=>"",
		BLANK_ALLOWED=>1,
                WIDGET_TYPE=>'entry', # can also be 'text' for multiline text
	        @_,
    );
    my $self = {};
    bless($self,$class);
    $self->{KEY} = $args{KEY};
    $self->{PROMPT} = $args{PROMPT};
    $self->{DEFAULT} = $args{DEFAULT};
    $self->{TYPE} = $args{TYPE};
    $self->{MAX} = $args{MAX};
    $self->{MIN} = $args{MIN};
    $self->{BLANK_ALLOWED} = $args{BLANK_ALLOWED};
    $self->{WIDGET_TYPE} = $args{WIDGET_TYPE};
    return $self;
}

sub check {
  my $self = shift;
  my $x = shift;
  my @stuff = ();
  if ($self->{TYPE} eq "numeric") {
    if ($self->{MIN} ne "" && $x<$self->{MIN}) {@stuff = ("below_min",$self->{MIN})}
    if ($self->{MAX} ne "" && $x>$self->{MAX}) {@stuff = ("above_max",$self->{MAX})}
  }
  if ($self->{TYPE} eq "string") {
    if ($x eq "" && !$self->{BLANK_ALLOWED}) {push @stuff,"blank_not_allowed"}
  }
  if (!@stuff) {return @stuff}
  @stuff[0] = $Browser::words->get("input.".$stuff[0]);
  return @stuff;
}

1;









