#----------------------------------------------------------------
# Copyright (c) 2002 Benjamin Crowell, all rights reserved.
#
# This software is available under version 2 of the GPL license.
# The software is copyrighted, and you must agree to the
# license in order to have permission to copy it. The full
# text of the license is given in the file titled Copying.
#
#----------------------------------------------------------------


use strict;
use File::Glob ':glob'; # handle whitespace in filenames correctly: Camel book, p. 890

package Preferences;

sub new {
  my $class = shift;
  my %args = (
                GB=>{},
                @_
                );
  my $self = {};
  bless($self,$class);

  my $file_name = 'OpenGrade_prefs';
  my @search = ();
  push @search,glob("~/.$file_name"); # Linux convention
  push @search,glob("~/Library/Preferences/$file_name"); # MacOS X convention
  push @search,glob("ogr.prf"); # Will this work on Windows?

  while (@search && !-e $search[0]) {shift @search}
  my $file;
  if (@search) {
    $file = $search[0];
  }
  else {
    # doesn't exist, so create it
    if (-e glob("~/Library/Preferences")) {
      $file = glob("~/Library/Preferences/$file_name"); # If that dir. exists, we're presumably on MacOS X.
    }
    else {
      $file = glob("~/.$file_name");
    }
    open F,">$file" or return $self;
    close F;
  }

  open F,"<$file" or return $self;
  close F or return $self;
  $self->{FILE} = $file;

  return $self;
}

sub get {
  my $self = shift;
  my $what = shift;
  local $/; # slurp whole file
  open F,"<".$self->{FILE} or return '';
  my $stuff = <F>;
  close F;
  if ($stuff =~ m/$what=\"([^\"]+)\"/) {
    return $1;
  }
  return '';
}

sub set {
  my $self = shift;
  my $what = shift;
  my $value = shift;
  local $/; # slurp whole file
  open F,"<".$self->{FILE} or return '';
  my $stuff = <F>;
  close F;
  if ($stuff =~ m/$what=\"([^\"]+)\"/) {
    $stuff =~ s/$what=\"[^\"]+\"/$what=\"$value\"/g;
  }
  else {
    $stuff = $stuff . "$what=\"$value\"\n";
  }
  open F,">".$self->{FILE} or return '';
  print F $stuff;
  close F;
  return 1;
}


1;
